import psutil
import os


def 根据名字获取磁盘路径(目标磁盘名: str) -> str:
    # Windows操作系统下,返回全部硬盘编号['C:\','D:\']
    # Mac/Linux下，返回硬盘名字
    所有磁盘信息 = psutil.disk_partitions()
    for item in 所有磁盘信息:
        i磁盘路径 = item.mountpoint
        i磁盘名 = os.path.basename(i磁盘路径)
        i磁盘属性 = item.opts
        # print(f"{i磁盘路径} -> {i磁盘属性}")
        if i磁盘名 == 目标磁盘名:
            return i磁盘路径


def 根据硬盘编号获取磁盘路径(目标磁盘编号: str = "Z:\\") -> str:
    # Windows操作系统下,返回全部硬盘编号['C:\','D:\']
    # Mac/Linux下，返回硬盘名字
    所有磁盘信息 = psutil.disk_partitions()
    for item in 所有磁盘信息:
        i磁盘路径: str = item.mountpoint
        i磁盘名 = item.device
        # i磁盘属性 = item.opts
        print(f"{i磁盘路径} -> {item.device},{目标磁盘编号},{item.device == 目标磁盘编号}")
        if i磁盘名 == 目标磁盘编号:
            return i磁盘路径


if __name__ == '__main__':
    print(根据名字获取磁盘路径("jm_backup") is None)
    print(根据名字获取磁盘路径("BOOTCAMP") is None)



import os
from typing import List, Tuple


def scan_file_扫描文件(filepath: str, suffix: str) -> List[Tuple[str, str]]:
    """
    扫描文件夹下所有符合条件的文件
    :param filepath:扫描路径
    :param suffix:过滤后缀
    :return:[(文件路径,文件名),...]
    """
    fileList = []
    print("开始扫描【{0}】".format(filepath))
    if not os.path.isdir(filepath):
        print("【{0}】不是目录".format(filepath))
        exit(-1)
    for filename in os.listdir(filepath):
        if os.path.isdir(filepath + "/" + filename):
            fileList.extend(scan_file_扫描文件(filepath + "/" + filename, suffix))
        else:
            if filename.endswith(suffix):
                fileList.append((filepath, filename))
    return fileList


def scan_file_扫描文件夹(filepath: str):
    """
    扫描指定文件夹下所有文件夹(去重)
    """
    dirs = scan_file_扫描文件(filepath=filepath, suffix="")
    dirs_files = [item[0] for item in dirs]
    #
    return list(set(dirs_files))


if __name__ == '__main__':
    path = "/Users/zhangxuewei/Documents/"
    fileLists = scan_file_扫描文件(path, "扫描文件.py")
    for item in fileLists:
        print(item)

    files = scan_file_扫描文件夹(path)
    print(files)



from distutils.core import setup


setup(
    name="file_operator_zxw",
    version="1.3",
    description="文件常用操作",
    author="XueWei Zhang",
    author_email="307080785@qq.com",
    py_modules=['file_operator_zxw.扫描文件','file_operator_zxw.创建文件夹','file_operator_zxw.识别移动硬盘',
                'file_operator_zxw.get项目根目录','file_operator_zxw.获取磁盘剩余空间','file_operator_zxw.创建excel流',
                'file_operator_zxw.获取文件占用空间',]
)



import os
import shutil


def get_free_space_GB(folder) -> tuple[float, float, float]:
    """
    获取磁盘剩余空间
    :param folder: 磁盘路径 例如 D:\\
    :return: 剩余空间,单位GB
    """
    print("当前硬盘空间检测路径:", os.path.dirname(folder))
    total, used, free = shutil.disk_usage("/")
    print("Total: %d GB" % (total // (2 ** 30)))
    print("Used: %d GB" % (used // (2 ** 30)))
    print("Free: %d GB" % (free // (2 ** 30)))
    return total / (2 ** 30), used / (2 ** 30), free / (2 ** 30)
